pygeai.tests.snippets.evaluation.dataset package
================================================

Submodules
----------

pygeai.tests.snippets.evaluation.dataset.complete\_workflow\_example module
---------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.complete_workflow_example
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.create\_dataset module
---------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.create_dataset
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.create\_dataset\_from\_file module
---------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.create_dataset_from_file
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.create\_dataset\_row module
--------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.create_dataset_row
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.create\_expected\_source module
------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.create_expected_source
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.create\_filter\_variable module
------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.create_filter_variable
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.delete\_dataset module
---------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.delete_dataset
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.delete\_dataset\_row module
--------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.delete_dataset_row
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.delete\_expected\_source module
------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.delete_expected_source
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.delete\_filter\_variable module
------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.delete_filter_variable
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.get\_dataset module
------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.get_dataset
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.get\_dataset\_row module
-----------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.get_dataset_row
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.get\_expected\_source module
---------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.get_expected_source
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.get\_filter\_variable module
---------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.get_filter_variable
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.list\_dataset\_rows module
-------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.list_dataset_rows
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.list\_datasets module
--------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.list_datasets
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.list\_expected\_sources module
-----------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.list_expected_sources
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.list\_filter\_variables module
-----------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.list_filter_variables
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.update\_dataset module
---------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.update_dataset
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.update\_dataset\_row module
--------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.update_dataset_row
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.update\_expected\_source module
------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.update_expected_source
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.update\_filter\_variable module
------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.update_filter_variable
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.dataset.upload\_dataset\_rows\_file module
---------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset.upload_dataset_rows_file
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: pygeai.tests.snippets.evaluation.dataset
   :members:
   :show-inheritance:
   :undoc-members:
